import cors from "cors";
import express from "express";
import fs from "node:fs";
import swaggerUi from "swagger-ui-express";
import yaml from "yaml";
import { productsRouter } from "./products/router";
import { authRouter } from "./auth/router";

// Create express app
const app = express();

// Setup Swagger UI for API documentation
const swaggerYaml = fs.readFileSync("./api-documentation/swagger.yaml", "utf8");
const swaggerDocument = yaml.parse(swaggerYaml);
// Alza doesn't want to expose its API documentation in the production environment (set the NODE_ENV variable in .env file)
if (process.env.NODE_ENV !== "production") {
  app.use(
    "/api-documentation",
    swaggerUi.serve,
    swaggerUi.setup(swaggerDocument)
  );
}

// Setup CORS
app.use(cors());

// Make express parse JSON in body and parse url encoded strings
app.use(express.json());
app.use(express.urlencoded({ extended: true }));

// TODO: setup passport! (maybe even create a separate file for this?)

// Register routers
app.use("/products", productsRouter);
app.use("/auth", authRouter);

// Default route returning 404
app.use((_req, res) => {
  res.status(404).send("Not found");
});

// Start listening on connections
app.listen(process.env.API_PORT, () =>
  console.log(`Alza.cz API listening on port ${process.env.API_PORT}`)
);
